==> sanjagh_flutter-0.0.1.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/BannerView.java <==
package com.sanjagh.sanjagh_flutter;

import android.content.Context;
import android.view.View;

import com.sanjagh.sdk.AdListener;
import com.sanjagh.sdk.BannerAdView;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

public class BannerView implements PlatformView, MethodChannel.MethodCallHandler, AdListener {
    private final BannerAdView bannerAdView;
    private final MethodChannel methodChannel;

    BannerView(Context context, BinaryMessenger messenger, int id, String adUnitId) {
        bannerAdView = new BannerAdView(context,adUnitId);
        bannerAdView.setAdListener(this);
        methodChannel = new MethodChannel(messenger, "com.sanjagh.sdk/banner_" + id);
        methodChannel.setMethodCallHandler(this);
    }

    @Override
    public View getView() {
        return bannerAdView;
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        switch (methodCall.method) {
            case "setText":
                setText(methodCall, result);
                break;
            default:
                result.notImplemented();
        }

    }

    private void setText(MethodCall methodCall, MethodChannel.Result result) {
        String text = (String) methodCall.arguments;
        result.success(null);
    }

    @Override
    public void dispose() {}

    @Override
    public void onAdLoaded() {
        methodChannel.invokeMethod("onAdLoaded", null);
    }

    @Override
    public void onAdFailedToLoad() {
        methodChannel.invokeMethod("onAdFailedToLoad", null);
    }

    @Override
    public void onNoAd() {
        methodChannel.invokeMethod("onNoAd", null);
    }

    @Override
    public void onNoNetwork() {
        methodChannel.invokeMethod("onNoNetwork",null);
    }

}

==> sanjagh_flutter-0.0.2.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/BannerView.java <==
package com.sanjagh.sanjagh_flutter;

import android.content.Context;
import android.view.View;

import com.sanjagh.sdk.AdListener;
import com.sanjagh.sdk.BannerAdView;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

public class BannerView implements PlatformView, MethodChannel.MethodCallHandler, AdListener {
    private final BannerAdView bannerAdView;
    private final MethodChannel methodChannel;

    BannerView(Context context, BinaryMessenger messenger, int id, String adUnitId) {
        bannerAdView = new BannerAdView(context,adUnitId);
        bannerAdView.setAdListener(this);
        methodChannel = new MethodChannel(messenger, "com.sanjagh.sdk/banner_" + id);
        methodChannel.setMethodCallHandler(this);
    }

    @Override
    public View getView() {
        return bannerAdView;
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        switch (methodCall.method) {
            case "setText":
                setText(methodCall, result);
                break;
            default:
                result.notImplemented();
        }

    }

    private void setText(MethodCall methodCall, MethodChannel.Result result) {
        String text = (String) methodCall.arguments;
        result.success(null);
    }

    @Override
    public void dispose() {}

    @Override
    public void onAdLoaded() {
        methodChannel.invokeMethod("onAdLoaded", null);
    }

    @Override
    public void onAdFailedToLoad(int errorCode) {
        methodChannel.invokeMethod("onAdFailedToLoad", null);
    }

    @Override
    public void onNoAd() {
        methodChannel.invokeMethod("onNoAd", null);
    }

    @Override
    public void onNoNetwork() {
        methodChannel.invokeMethod("onNoNetwork",null);
    }

}
